import React, { useEffect, useState, RefObject } from 'react';
import * as d3 from 'd3';

const getValues = async (granularite: string, dateDebut: string, dateFin: string) => {
    const data = await fetch('/ventes/nombre?granularite='+granularite+'&dateDebut='+dateDebut+'&dateFin='+dateFin)
                        .then(response => response.json())

    return data['hydra:member'];
}

type DataPoint = { label: string; value: number; };

const BarChart = () => {
    const ref: RefObject<HTMLDivElement> = React.createRef();

    const dataShow = [
        {id: '/ventes/nombre/2022-01-03', type: 'NombreVentes', date: '2022-01-03T00:00:00+00:00', quantite: 183},
        {id: '/ventes/nombre/2022-01-04', type: 'NombreVentes', date: '2022-01-04T00:00:00+00:00', quantite: 293},
        {id: '/ventes/nombre/2022-01-05', type: 'NombreVentes', date: '2022-01-05T00:00:00+00:00', quantite: 296},
        {id: '/ventes/nombre/2022-01-06', type: 'NombreVentes', date: '2022-01-06T00:00:00+00:00', quantite: 440},
        {id: '/ventes/nombre/2022-01-07', type: 'NombreVentes', date: '2022-01-07T00:00:00+00:00', quantite: 531},
    ];

    const [data, setData] = useState(dataShow);
    const [interval, setInterval] = useState("");
    const [dateDebut, setDateDebut] = useState("");
    const [dateFin, setDateFin] = useState("");

    useEffect(() => {
        /*const fetchData = async () => {
            const data = await getValues("jour", "2021-01-01", "2021-01-07");
            setData(data);
        };
        
        fetchData();*/
        draw();
    });
    

    const draw = () => {
        const container = ref.current;
        if (!container) return;

        var margin = { top: 30, right: 30, bottom: 70, left: 60 },
                    width = 460 - margin.left - margin.right,
                    height = 400 - margin.top - margin.bottom;

        var svg = d3.select(container)
                    .append("svg")
                    .attr("width", width + margin.left + margin.right)
                    .attr("height", height + margin.top + margin.bottom)
                    .append("g")
                    .attr("transform", "translate(" + margin.left + "," + margin.top + ")");

        // X axis
        var x = d3.scaleBand()
                .range([0, width])
                .domain(
                    data.map(function (d: any) {
                        return d.date.substring(0, 10);
                    })
                )
                .padding(0.2);

        svg.append("g")
            .attr("transform", "translate(0," + height + ")")
            .call(d3.axisBottom(x))
            .selectAll("text")
            .attr("transform", "translate(-10,0)rotate(-45)")
            .style("text-anchor", "end");

        // Y axis
        var max = Math.max(...data.map(o => o.quantite)) * 1.2
        var y = d3.scaleLinear().domain([0, max]).range([height, 0]);

        svg.append("g").call(d3.axisLeft(y));

        // Data
        svg.selectAll(".block")
            .data(data)
            .enter()
            .append("rect")
            .attr("class", "bar")
            .attr("x", function (d: any) {
                return x(d.date.substring(0, 10));
            })
            .attr("width", x.bandwidth())
            .attr("y", function (d: any) {
                return y(d.quantite);
            })
            .attr("height", function (d: any) {
                return height - y(d.quantite);
            })
            .attr("fill", "#69b3a2");
    }

    const handleChangeInterval = event => {
        setInterval(event.target.value)
        console.log("New interval : " + event.target.value)
    }

    const handleDateDebutChange = event => {
        setDateDebut(event.target.value)
        console.log("New DateDebut : " + event.target.value)
    }

    const handleDateFinChange = event => {
        setDateFin(event.target.value)
        console.log("New DateFin : " + event.target.value)
    }

    return (
        <div className="BarChart" ref={ref}>
            <p>
                <label>Choisissez un intervalle &nbsp;</label>
                <select name="sort" id="intervalle" onChange={handleChangeInterval}>
                    <option value="jour">Jour</option>
                    <option value="mois">Mois</option>
                    <option value="annee">Année</option>
                </select>
            </p>
            
            <p>
                <label>Date de début &nbsp;</label>
                <input type="date" id="date_start" name="trip-start" defaultValue="2022-01-01" min="2018-01-01" max="2021-12-31" onChange={handleDateDebutChange}/>
            </p>

            <p>
                <label>Date de fin &nbsp;</label>
                <input type="date" id="date_end" name="trip-end" defaultValue="2022-01-07" min="2018-01-01" max="2021-12-31" onChange={handleDateFinChange}/>
            </p>
        </div>
    );
}

export default BarChart;